==> e107-0.7.20.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_conf.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/forum/languages/English/lan_forum_conf.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("FORLAN_5", "Poll deleted.");
define("FORLAN_6", "Thread deleted");
define("FORLAN_7", "replies deleted");
define("FORLAN_8", "Delete cancelled.");
define("FORLAN_9", "Thread moved.");
define("FORLAN_10", "Move cancelled.");
define("FORLAN_11", "Back To Forums");
define("FORLAN_12", "Forum Configuration");
define("FORLAN_13", "Are you absolutely certain you want to delete this poll?<br />Once deleted it <b><u>cannot</u></b> be retrieved.");
define("FORLAN_14", "Cancel");
define("FORLAN_15", "Confirm Delete Forum Post");
define("FORLAN_16", "Confirm Delete Poll");
define("FORLAN_17", "posted by");
define("FORLAN_18", "Are you absolutely certain you want to delete this forum");
define("FORLAN_19", "thread and it's related posts?");
define("FORLAN_20", "the poll will also be deleted");
define("FORLAN_21", "Once deleted they");
define("FORLAN_22", "post?<br />Once deleted it");
define("FORLAN_23", "cannot</u></b> be retrieved");
define("FORLAN_24", "Move thread  to forum");
define("FORLAN_25", "Move Thread");
define("FORLAN_26", "Reply deleted");

define("FORLAN_27", "moved");

define("FORLAN_28", "Do not rename thread title");
define("FORLAN_29", "Add");
define("FORLAN_30", "to title");
define("FORLAN_31", "Rename to:");
define("FORLAN_32", "Rename thread options:");


?>

==> e107-1.0.0.tbz: www/e107/e107_plugins/forum/languages/English/lan_forum_conf.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/forum/languages/English/lan_forum_conf.php $
|     $Revision: 11678 $
|     $Id: lan_forum_conf.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("FORLAN_5", "Poll deleted.");
define("FORLAN_6", "Thread deleted");
define("FORLAN_7", "replies deleted");
define("FORLAN_8", "Delete cancelled.");
define("FORLAN_9", "Thread moved.");
define("FORLAN_10", "Move cancelled.");
define("FORLAN_11", "Back To Forums");
define("FORLAN_12", "Forum Configuration");
define("FORLAN_13", "Are you absolutely certain you want to delete this poll?<br />Once deleted it <b><u>cannot</u></b> be retrieved.");
define("FORLAN_14", "Cancel");
define("FORLAN_15", "Confirm Delete Forum Post");
define("FORLAN_16", "Confirm Delete Poll");
define("FORLAN_17", "posted by");
define("FORLAN_18", "Are you absolutely certain you want to delete this forum");
define("FORLAN_19", "thread and it's related posts?");
define("FORLAN_20", "the poll will also be deleted");
define("FORLAN_21", "Once deleted they");
define("FORLAN_22", "post?<br />Once deleted it");
define("FORLAN_23", "cannot</u></b> be retrieved");
define("FORLAN_24", "Move thread  to forum");
define("FORLAN_25", "Move Thread");
define("FORLAN_26", "Reply deleted");

define("FORLAN_27", "moved");

define("FORLAN_28", "Do not rename thread title");
define("FORLAN_29", "Add");
define("FORLAN_30", "to title");
define("FORLAN_31", "Rename to:");
define("FORLAN_32", "Rename thread options:");


?>
